[![Build Status](https://travis-ci.org/opengridcc/opengrid.svg?branch=develop)](https://travis-ci.org/opengridcc/opengrid)
[![Coverage Status](https://coveralls.io/repos/opengridcc/opengrid/badge.svg?branch=develop&service=github)](https://coveralls.io/github/opengridcc/opengrid)

opengrid
========

Open-source algorithms for data-driven building analysis and control

License: Apache 2.0

